/***************************************************************
 * Name:      wxiscanabout.h
 * Purpose:   Defines About Box Class.
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2009-06-12
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:   GPL
 **************************************************************/

#ifndef WXISCANABOUT_H
#define WXISCANABOUT_H

#ifndef WX_PRECOMP
	//(*HeadersPCH(wxIScanAbout)
	#include <wx/dialog.h>
	#include <wx/sizer.h>
	//*)
#endif
//(*Headers(wxIScanAbout)
#include <wx/html/htmlwin.h>
//*)


//////////////////////////////////////////////////////////
// Strings and other (global) constants
//
extern const wxString cstrAppName;          ///< Application name string.
extern const wxString cstrAppDescription;   ///< Short application description string.
extern const wxString cstrVendor;           ///< Vendor information.
extern const wxString cstrStatusCopyRight;  ///< Copyright string in the status bar.
extern const wxString cstrVersionString;    ///< Version information.
extern const wxString cstrWebSite;          ///< Web site string.
extern const wxString cstrWxVersionString;  ///< wxWidgets version information.
#if __WXLUASCRIPT__
extern const wxString cstrLuaVersion;       ///< Lua version string.
#endif // __WXLUASCRIPT__


//////////////////////////////////////////////////////////
// Class wxIScanAbout
//
/// \brief The program's about dialog.
///
/// This Dialog shows information on this application
/// and the licenses it is based on. The main part is
/// a wxHtmlWindow (derived from wxHtmlWindow) so you
/// can click on most elements and a browser opens the
/// corresponding link.
class wxIScanAbout: public wxDialog
{
	public:
        /// \brief Standard constructor.
        ///
        /// \param poParent     a pointer to the parent window
        /// \param nId          the window id, defaults to wxID_ANY
		wxIScanAbout( wxWindow* poParent, wxWindowID nId= wxID_ANY );

        /// \brief Virtual destructor.
		virtual ~wxIScanAbout();

		//(*Declarations(wxIScanAbout)
		//*)

	private:
		//(*Identifiers(wxIScanAbout)
		//*)

		//(*Handlers(wxIScanAbout)
		void OnInit(wxInitDialogEvent& event);
		//*)

		DECLARE_EVENT_TABLE()
};


//////////////////////////////////////////////////////////
// Class wxAboutHtmlWindow
//
/// \brief A (slightly) extended html window class.
///
/// It extends wxHtmlWindow in the way that clicks on links
/// are caught and an external browser is started with the
/// link instead of onpening the link in the html window
/// itself.
class wxAboutHtmlWindow : public wxHtmlWindow
{
  public:
    /// \brief Standard constructor copied from wxHtmlWindow.
    ///
    /// \param poParent     a pointer to the parent window
    /// \param nId          the window id, defaults to wxID_ANY
    /// \param oPos         the window position on the screen, defaults to wxDefaultPosition
    /// \param oSize        the window size, defaults to wxDefaultSize
    /// \param nStyle       the (html) window style, defaults to wxHW_DEFAULT_STYLE
    /// \param strName      the class name, defaults to "wxAboutHtmlWindow"
    wxAboutHtmlWindow(
                    wxWindow *poParent,
                    wxWindowID nId = wxID_ANY,
                    const wxPoint& oPos= wxDefaultPosition,
                    const wxSize& oSize= wxDefaultSize,
                    long nStyle= wxHW_DEFAULT_STYLE,
                    const wxString& strName= wxT( "wxAboutHtmlWindow" )
                )
      : wxHtmlWindow( poParent, nId, oPos, oSize, nStyle, strName )
    {
    }

  private:
    /// \brief Handler for clicking on a link events.
    ///
    /// It passes the link to an external browser (the system's
    /// default browser). This prevents the about window to show
    /// the linked page itself.
    void OnLinkClicked( wxHtmlLinkEvent &oEvent )
    {
        ::wxLaunchDefaultBrowser( oEvent.GetLinkInfo().GetHref() );
    }

  private:
    DECLARE_EVENT_TABLE()
};
#endif
