--[[**********************************************************
    * Name:      wxiscanadddirtopdf.lua
    * Purpose:   Advanced sample for implementing Lua addons
    *            for wxIScan.
    * Author:    Daniel Nell (daniel.nell@nellresearch.de)
    * Created:   2010-08-10
    * Copyright: Daniel Nell (www.nellresearch.de)
    * License:   GPL
    **********************************************************
--]]



-------------------------------------------------------------
-- Required Lua module.
--
require "lfs"	-- Lua filesystem module



-------------------------------------------------------------
-- Usefull functions calling menu handlers on the C++ side.
--
-- Add the current loaded image as a new page to the
-- current PDF document.
--
function PdfAddPage()
    return wxIScan.SendMenuEvent( ID_PDFADDPAGE )
end

-- Apply the current image profile to the current image.
--
function DocumentApplyProfile()
    return wxIScan.SendMenuEvent( ID_DOCUMENTAPPLYPROFILE )
end



-------------------------------------------------------------
-- Main chunk(s)
-- (referred by the "Script" section in the config file).
--
-- Add the content of a whole directory to the
-- currenct PDF document file by file.
--
function AddDirToPDF( Directory )
    -- Handle default parameter(s).
    if Directory == nil then
        Directory= "."
    end

    -- Local variables
    local FileNames= {}
    local FileName
    local FileAttr

    -- Collect the filename of the given directory, ...
    for FileName in lfs.dir( Directory ) do
        if string.sub( FileName, 1, 1 ) ~= "." then
            FileAttr = lfs.attributes( FileName )
            if( FileAttr.mode == "file" ) then
                table.insert( FileNames, FileName )
            end
        end
    end

    -- ... sort them, and ...
    table.sort( FileNames )

    -- ...add the files to the currenct PDF document.
    for i= 1, table.maxn( FileNames ), 1 do

        -- Open image (and check success).
        if wxIScan.OpenImage( FileNames[i] ) then

            -- Apply image transformations according to the current profile
            DocumentApplyProfile()

            -- Add the resulting image to the PDF document.
            PdfAddPage()
        end
    end
end

